from fhirkit import Observation
from fhirkit import SimpleFHIRStore
from fhirkit.elements.elements import Identifier, Reference


def test_resource_with_reference():
    store = SimpleFHIRStore()

    literal_ref = Reference(reference=f"Patient/123")

    observation = Observation(code={"text": "bloeddruk"}, value="hoog")
    # create reference given resource

    ref = store.create_reference(observation)

    # retrieve resource from reference
    resource = ref.resolve(store)



from fhirkit.elements import Meta
from fhirkit.primitive_datatypes import URI
from pydantic import parse_obj_as

source="ANONIEM_id 1602 CAS.xlsx#R0"
parse_obj_as(URI, source)
meta=Meta(source=source)
#print(Meta())
#meta=Meta(source=source)
#print(meta)RI
    
